@@ -12,13 +12,13 @@ struct _E_Obj_Dialog
 {
    E_Object             e_obj_inherit;
 
-   E_Win               *win;
+   Evas_Object         *win;
    Evas_Object         *bg_object;
    void                *data;
    void		       (*cb_delete)(E_Obj_Dialog *od);
 };
 
-E_API E_Obj_Dialog   *e_obj_dialog_new(E_Comp *c, char *title, char *class_name, char *class_class);
+E_API E_Obj_Dialog   *e_obj_dialog_new(char *title, char *class_name, char *class_class);
 E_API void            e_obj_dialog_icon_set(E_Obj_Dialog *od, char *icon);
 E_API void            e_obj_dialog_show(E_Obj_Dialog *od);
 E_API void            e_obj_dialog_obj_part_text_set(E_Obj_Dialog *od, const char *part, const char *text);
