@@ -11,10 +11,13 @@ typedef struct _E_Config_Randr2_Screen E_Config_Randr2_Screen;
 #ifndef E_RANDR2_H
 #define E_RAND2R_H
 
-#define E_RANDR_VERSION_1_1 ((1 << 16) | 1)
-#define E_RANDR_VERSION_1_2 ((1 << 16) | 2)
-#define E_RANDR_VERSION_1_3 ((1 << 16) | 3)
-#define E_RANDR_VERSION_1_4 ((1 << 16) | 4)
+typedef enum
+{
+   E_RANDR2_POLICY_NONE,
+   E_RANDR2_POLICY_EXTEND,
+   E_RANDR2_POLICY_CLONE,
+   E_RANDR2_POLICY_ASK,
+} E_Randr2_Policy;
 
 typedef enum _E_Randr2_Relative
 {
@@ -58,6 +61,7 @@ struct _E_Randr2_Screen
       char                 *name; // name of the output itself
       char                 *edid; // full edid data
       E_Randr2_Connector    connector; // the connector type
+      unsigned int          subpixel; //ecore_drm2_output_subpixel_get
       Eina_Bool             is_lid : 1; // is an internal screen
       Eina_Bool             lid_closed : 1; // is lid closed when screen qury'd
       Eina_Bool             connected : 1; // some screen is plugged in or not
@@ -96,6 +100,7 @@ struct _E_Config_Randr2
    unsigned char  restore;
    unsigned char  ignore_hotplug_events;
    unsigned char  ignore_acpi_events;
+   E_Randr2_Policy default_policy;
 };
 
 struct _E_Config_Randr2_Screen
@@ -132,6 +137,6 @@ E_API E_Config_Randr2_Screen *e_randr2_config_screen_find(E_Randr2_Screen *s, E_
 E_API void                    e_randr2_screens_setup(int rw, int rh);
 E_API E_Randr2_Screen        *e_randr2_screen_id_find(const char *id);
 E_API double                  e_randr2_screen_dpi_get(E_Randr2_Screen *s);
-
+E_API void                     e_randr2_screen_modes_sort(E_Randr2_Screen *s);
 #endif
 #endif
